package com.ruoyi.common.utils;

import com.itextpdf.text.*;
import com.itextpdf.text.pdf.BaseFont;
import com.itextpdf.text.pdf.PdfPCell;

import java.io.IOException;

/**
 * PDF工具类
 * @author gxk
 */
public class PdfUtils {

    /**
     * 标题
     * @param content
     * @return
     * @throws IOException
     * @throws DocumentException
     */
    public static Paragraph createTitle(String content) throws IOException, DocumentException {
        Font font = new Font(getBaseFont(), 24, Font.BOLD);
        Paragraph paragraph = new Paragraph(content, font);
        paragraph.setAlignment(Element.ALIGN_CENTER);
        return paragraph;
    }

    /**
     * H1标题
     * @param content
     * @return
     * @throws IOException
     * @throws DocumentException
     */
    public static Paragraph createChapterH1(String content) throws IOException, DocumentException {
        Font font = new Font(getBaseFont(), 22, Font.BOLD);
        Paragraph paragraph = new Paragraph(content, font);
        paragraph.setAlignment(Element.ALIGN_LEFT);
        return paragraph;
    }

    /**
     * H2标题
     * @param content
     * @return
     * @throws IOException
     * @throws DocumentException
     */
    public static Paragraph createChapterH2(String content) throws IOException, DocumentException {
        Font font = new Font(getBaseFont(), 18, Font.BOLD);
        Paragraph paragraph = new Paragraph(content, font);
        paragraph.setAlignment(Element.ALIGN_LEFT);
        return paragraph;
    }

    /**
     * 段
     * @param content
     * @return
     * @throws IOException
     * @throws DocumentException
     */
    public static Paragraph createParagraph(String content) throws IOException, DocumentException {
        Font font = new Font(getBaseFont(), 12, Font.NORMAL);
        Paragraph paragraph = new Paragraph(content, font);
        paragraph.setAlignment(Element.ALIGN_LEFT);
        // 设置左缩进
        paragraph.setIndentationLeft(12);
        // 设置右缩进
        paragraph.setIndentationRight(12);
        // 设置首行缩进
        paragraph.setFirstLineIndent(24);
        // 行间距
        paragraph.setLeading(20f);
        // 设置段落上空白
        paragraph.setSpacingBefore(5f);
        // 设置段落下空白
        paragraph.setSpacingAfter(10f);
        return paragraph;
    }

    /**
     * 表格内容
     * @param content
     * @return
     * @throws IOException
     * @throws DocumentException
     */
    public static PdfPCell createCell(String content) throws IOException, DocumentException {
        PdfPCell cell = new PdfPCell();
        cell.setVerticalAlignment(Element.ALIGN_MIDDLE);
        cell.setHorizontalAlignment(Element.ALIGN_CENTER);
        Font font = new Font(getBaseFont(), 12, Font.NORMAL);
        cell.setPhrase(new Phrase(content, font));
        return cell;
    }

    /**
     * 字体
     * @return
     * @throws IOException
     * @throws DocumentException
     */
    public static BaseFont getBaseFont() throws IOException, DocumentException {
        return BaseFont.createFont("STSong-Light", "UniGB-UCS2-H", BaseFont.NOT_EMBEDDED);
    }

}
